@@ -46,8 +46,8 @@ static Options opts[] = {
 };
 
 int read_options(char *filename, Option *option);
-int find_parnum(FILE *fd, int parnum);
-int getword(FILE *fd, char *opt); 
-int check_char(int ch);  
+int find_parameters(const char *buffer, int len, Option *option);
+void get_parameters(char *line, Option *option);
+int checkline(char *buf);
 
 #endif
